@@ -97,8 +97,6 @@ namespace
 
     virtual ~lStat( );
 
-    std::ostream& Dump( std::ostream& Stream ) const;
-
     //-------------------------------------------------------------------
     /// \brief Action to be done when task completes
     //-------------------------------------------------------------------
@@ -240,13 +238,6 @@ namespace {
   {
   }
 
-  std::ostream& lStat::
-  Dump( std::ostream& Stream ) const
-  {
-    Stream << "lStat: " << m_path;
-    return Stream;
-  }
-
   //---------------------------------------------------------------------
   /// This actually does the system call.
   /// The local buffer is used to prevent memory corruuption in the
